==> com.liferay.layout.content.page.editor.web-2.0.74.jar: META-INF/resources/page_editor/plugins/page-design-options/hooks/useStyleBook.js <==
Liferay.Loader.define("layout-content-page-editor-web@2.0.74/page_editor/plugins/page-design-options/hooks/useStyleBook", ['module', 'exports', 'require', 'frontend-js-react-web$react', '../../../app/config/index'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    function _typeof(obj) {
      "@babel/helpers - typeof";
      if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
        _typeof = function _typeof(obj) {
          return typeof obj;
        };
      } else {
        _typeof = function _typeof(obj) {
          return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
        };
      }return _typeof(obj);
    }

    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.useStyleBook = exports.useSetStyleBook = exports.StyleBookContextProvider = void 0;

    var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

    var _index = require("../../../app/config/index");

    function _getRequireWildcardCache() {
      if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
        return cache;
      };return cache;
    }

    function _interopRequireWildcard(obj) {
      if (obj && obj.__esModule) {
        return obj;
      }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
        return { "default": obj };
      }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
        return cache.get(obj);
      }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
        if (Object.prototype.hasOwnProperty.call(obj, key)) {
          var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
            Object.defineProperty(newObj, key, desc);
          } else {
            newObj[key] = obj[key];
          }
        }
      }newObj["default"] = obj;if (cache) {
        cache.set(obj, newObj);
      }return newObj;
    }

    function _slicedToArray(arr, i) {
      return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
    }

    function _nonIterableRest() {
      throw new TypeError("Invalid attempt to destructure non-iterable instance");
    }

    function _iterableToArrayLimit(arr, i) {
      if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) {
        return;
      }var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
        for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
          _arr.push(_s.value);if (i && _arr.length === i) break;
        }
      } catch (err) {
        _d = true;_e = err;
      } finally {
        try {
          if (!_n && _i["return"] != null) _i["return"]();
        } finally {
          if (_d) throw _e;
        }
      }return _arr;
    }

    function _arrayWithHoles(arr) {
      if (Array.isArray(arr)) return arr;
    }

    var StyleBookDispatchContext = _react["default"].createContext(function () {});

    var StyleBookStateContext = _react["default"].createContext({
      defaultStyleBookEntryName: '',
      imagePreviewURL: '',
      styleBookEntryId: '',
      tokenValues: {}
    });

    var StyleBookContextProvider = function StyleBookContextProvider(_ref) {
      var children = _ref.children;

      var _useState = (0, _react.useState)({
        defaultStyleBookEntryName: _index.config.defaultStyleBookEntryName,
        imagePreviewURL: _index.config.defaultStyleBookEntryImagePreviewURL,
        styleBookEntryId: _index.config.styleBookEntryId,
        tokenValues: _index.config.frontendTokens
      }),
          _useState2 = _slicedToArray(_useState, 2),
          styleBook = _useState2[0],
          setStyleBook = _useState2[1];

      return _react["default"].createElement(StyleBookDispatchContext.Provider, {
        value: setStyleBook
      }, _react["default"].createElement(StyleBookStateContext.Provider, {
        value: styleBook
      }, children));
    };

    exports.StyleBookContextProvider = StyleBookContextProvider;

    var useSetStyleBook = function useSetStyleBook() {
      return (0, _react.useContext)(StyleBookDispatchContext);
    };

    exports.useSetStyleBook = useSetStyleBook;

    var useStyleBook = function useStyleBook() {
      return (0, _react.useContext)(StyleBookStateContext);
    };

    exports.useStyleBook = useStyleBook;
    //# sourceMappingURL=useStyleBook.js.map
  }
});
//# sourceMappingURL=useStyleBook.js.map

==> com.liferay.layout.content.page.editor.web-2.0.122.jar: META-INF/resources/page_editor/plugins/page-design-options/hooks/useStyleBook.js <==
Liferay.Loader.define("layout-content-page-editor-web@2.0.122/page_editor/plugins/page-design-options/hooks/useStyleBook", ['module', 'exports', 'require', 'frontend-js-react-web$react', '../../../app/config/index'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    function _typeof(obj) {
      "@babel/helpers - typeof";
      if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
        _typeof = function _typeof(obj) {
          return typeof obj;
        };
      } else {
        _typeof = function _typeof(obj) {
          return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
        };
      }return _typeof(obj);
    }

    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.useStyleBook = exports.useSetStyleBook = exports.StyleBookContextProvider = void 0;

    var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

    var _index = require("../../../app/config/index");

    function _getRequireWildcardCache() {
      if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
        return cache;
      };return cache;
    }

    function _interopRequireWildcard(obj) {
      if (obj && obj.__esModule) {
        return obj;
      }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
        return { default: obj };
      }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
        return cache.get(obj);
      }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
        if (Object.prototype.hasOwnProperty.call(obj, key)) {
          var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
            Object.defineProperty(newObj, key, desc);
          } else {
            newObj[key] = obj[key];
          }
        }
      }newObj.default = obj;if (cache) {
        cache.set(obj, newObj);
      }return newObj;
    }

    function _slicedToArray(arr, i) {
      return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
    }

    function _nonIterableRest() {
      throw new TypeError("Invalid attempt to destructure non-iterable instance");
    }

    function _iterableToArrayLimit(arr, i) {
      if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) {
        return;
      }var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
        for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
          _arr.push(_s.value);if (i && _arr.length === i) break;
        }
      } catch (err) {
        _d = true;_e = err;
      } finally {
        try {
          if (!_n && _i["return"] != null) _i["return"]();
        } finally {
          if (_d) throw _e;
        }
      }return _arr;
    }

    function _arrayWithHoles(arr) {
      if (Array.isArray(arr)) return arr;
    }

    var StyleBookDispatchContext = /*#__PURE__*/_react.default.createContext(function () {});

    var StyleBookStateContext = /*#__PURE__*/_react.default.createContext({
      styleBookEntryId: '',
      tokenValues: {}
    });

    var StyleBookContextProvider = function StyleBookContextProvider(_ref) {
      var children = _ref.children;

      var _useState = (0, _react.useState)({
        styleBookEntryId: _index.config.styleBookEntryId,
        tokenValues: _index.config.frontendTokens
      }),
          _useState2 = _slicedToArray(_useState, 2),
          styleBook = _useState2[0],
          setStyleBook = _useState2[1];

      return (/*#__PURE__*/_react.default.createElement(StyleBookDispatchContext.Provider, {
          value: setStyleBook
        }, /*#__PURE__*/_react.default.createElement(StyleBookStateContext.Provider, {
          value: styleBook
        }, children))
      );
    };

    exports.StyleBookContextProvider = StyleBookContextProvider;

    var useSetStyleBook = function useSetStyleBook() {
      return (0, _react.useContext)(StyleBookDispatchContext);
    };

    exports.useSetStyleBook = useSetStyleBook;

    var useStyleBook = function useStyleBook() {
      return (0, _react.useContext)(StyleBookStateContext);
    };

    exports.useStyleBook = useStyleBook;
    //# sourceMappingURL=useStyleBook.js.map
  }
});
//# sourceMappingURL=useStyleBook.js.map
